@@ -16,7 +16,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
 #  USA
 #
-# Version 1.5 last modified on August 22nd, 2009.
+# Version 1.6 last modified on August 22nd, 2009.
 #
 #!/bin/bash
 # start wish \
@@ -227,11 +227,11 @@ set idhole(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img(0)]
 
 .cnv delete $indication
 if {$level=="H"} {
-   set indication [.cnv create text 70 30 \
-   -text "$P1CO($LANG) $score(1)\n$P2CO($LANG) $score(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
+   set indication [.cnv create text 20 30 \
+   -text "$P1CO($LANG) $score(1)\n$P2CO($LANG) $score(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn" -anchor w]
 } else {
-   set indication [.cnv create text 70 30 \
-   -text "$CSCO($LANG) $score(1)\n$PSCO($LANG) $score(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
+   set indication [.cnv create text 20 30 \
+   -text "$CSCO($LANG) $score(1)\n$PSCO($LANG) $score(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn" -anchor w]
 }
 
 # highlights just played hole
@@ -343,13 +343,14 @@ proc displayDistribution {awaleoutput} {
   global hole score label
   global turn iturn
 
+  scan [string range $awaleoutput [string first "move=" $awaleoutput] end] "move=%d" mvt
+  displaySeeds $mvt
   set lines [split $awaleoutput "\n"]
   foreach line $lines {
     scan $line "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
                 hole(0) hole(1) hole(2) hole(3) hole(4) hole(5) \
                 hole(6) hole(7) hole(8) hole(9) hole(10) hole(11) \
                 score(0) score(1) mvt label
-#tk_messageBox -message "$line mvt=$mvt"
     displaySeeds $mvt
   }
   if {$label!="ERR"} {set turn([incr iturn]) $line}
@@ -516,16 +517,19 @@ toplevel .rule -borderwidth 1 -relief sunken
 set flag_uk [image create photo -file [file join $BIN uk.gif]]
 set flag_fr [image create photo -file [file join $BIN fr.gif]]
 set flag_sp [image create photo -file [file join $BIN sp.gif]]
+set flag_de [image create photo -file [file join $BIN de.gif]]
 frame .rule.flag
 button .rule.flag.uk -image $flag_uk -command rule_uk
 button .rule.flag.fr -image $flag_fr -command rule_fr
 button .rule.flag.sp -image $flag_sp -command rule_sp
+button .rule.flag.de -image $flag_de -command rule_de
 text .rule.txt -relief sunken -bd 2 -yscrollcommand ".rule.scroll set" -setgrid 1 \
  -height 37 -width 100 -spacing2 5;
 scrollbar .rule.scroll -command ".rule.txt yview"
 pack .rule.flag.uk -side left -padx 5 -pady 5
 pack .rule.flag.fr -side left -padx 5 -pady 5
 pack .rule.flag.sp -side left -padx 5 -pady 5
+pack .rule.flag.de -side left -padx 5 -pady 5
 pack .rule.flag -side top -anchor w
 pack .rule.scroll -side right -fill y
 pack .rule.txt -expand yes -fill both
@@ -611,6 +615,36 @@ configurant la rgle avec les quatre paramtres suivants.
 }
 }
 
+proc rule_de {} {
+.rule.txt delete 0.0 end
+.rule.txt insert 0.0 \
+{Awale-Regeln
+
+Das Awale-Spielbrett besteht aus zwei Reihen mit je sechs Mulden. Jedem Spieler gehrt eine Reihe, die obere dem Computer, die untere dem menschlichen Spieler. Noch je zwei Mulden sind fr die gefangenen Samen.
+
+Jede Mulde enthlt am Anfang des Spiels vier Samen.
+
+Die Spieler spielen je einen Zug abwechselnd, ohne zwei Zge hintereinander zu machen oder auszusetzen.
+
+Ein Zug besteht darin, alle Samen aus einer eigenen Mulde zu nehmen und sie im Gegenuhrzeigersinn einzeln in die darauffolgenden Mulden zu legen, wobei kein Samen in die Startmulde abgelegt werden darf (dies tritt auf, wenn in der Startmulde mindestens zulf Samen sind).
+
+Die Samen der Endmulde werden gefangen, wenn sie auf der Seite des Gegners liegt und nach Verteilung aller Samen zwei oder drei Samen beinhaltet. Die Samen aller vorausgehenden Mulden, die ebenfalls diese Bedingungen erfllen, werden ebenfalls gefangen. Man kann jeweils hchstens die Samen der letzten vier Mulden fangen. Wenn es mehr sind, werden nur die letzten vier gefangen.
+
+Man darf nur so spielen, da dem Gegner mindestens ein Stein verbleibt. Ist dies unmglich, hrt das Spiel auf.
+
+Der Sieger ist derjenige mit den meisten gefangenen Samen.
+
+
+VARIANTEN
+
+In Afrika gibt es viele Varianten dieses Spiels. Die meisten von ihnen knnen dadurch gespielt werden, da man folgende Parameter einstellt:
+- Die maximale Anzahl E der Mulden mit gefangenen Samen (1-6)
+- Gar keinen Samen fangen, anstatt die Samen der letzten E Mulden zu fangen, wenn mehr als eine angegriffen wird
+- Man kann verbieten, da alle gegnerischen Samen angegriffen werden, es sei denn, dies ist der einzig mgliche Zug
+- Wenn alle gegnerischen Samen angegriffen werden, wird kein Samen gefangen.
+}
+}
+
 proc rule_uk {} {
 .rule.txt delete 0.0 end
 .rule.txt insert 0.0 \
@@ -723,74 +757,85 @@ set indication 0
 array set Tmin [list 0 0   1 1 2 3  3 15]
 array set Tmax [list 0 999 1 2 2 20 3 100]
 
-array set SEED [list uk "seed(s)"        fr "graine(s)"          sp "semilla(s)"]
-array set PLAY [list uk "Play"           fr "Jeu"                sp "Jugar"]
-array set NEW  [list uk "New game"       fr "Nouvelle partie"    sp "Nueva partida"]
-array set OPEN [list uk "Open"           fr "Ouvrir"             sp "Abrir"]
-array set SAVE [list uk "Save"           fr "Sauver"             sp "Guardar"]
-array set UNDO [list uk "Undo"           fr "Annuler"            sp "Anular"]
-array set QUIT [list uk "Quit"           fr "Quitter"            sp "Salir"]
-array set PARA [list uk "Parameters"     fr "Paramtres"         sp "Parmetros"]
-array set LEVE [list uk "Level"          fr "Niveau"             sp "Nivel"]
-array set TWOP [list uk "Two players"    fr "Deux joueurs"       sp "Dos jugadores"]
-array set OPPO [list uk "Computer level" fr "Ordinateur niveau"  sp "Ordenador nivel"]
-array set STAR [list uk "First turn"     fr "Premier coup"       sp "Primer turno"]
-array set LING [list uk "Language"       fr "Language"           sp "Lengua"]
-array set BOTT [list uk "Bottom"         fr "Bas"                sp "Abajo"]
-array set TOP  [list uk "Top"            fr "Haut"               sp "Arriba"]
-array set CONF [list uk "Configure rule" fr "Configurer la rgle" sp "Configurar las reglas"]
-array set DETA [list uk "Detailed rule"  fr "Rgle dtaille"    sp "Reglas detalladas"]
-array set HELP [list uk "Help"           fr "Aide"               sp "Ayuda"]
-array set RULE [list uk "Rules"          fr "Rgles"             sp "Reglas"]
-array set ABOU [list uk "About"          fr "A propos"           sp "Sobre"]
-array set UK   [list uk "English"        fr "English"            sp "English"]
-array set FR   [list uk "Franais"       fr "Franais"           sp "Franais"]
-array set SP   [list uk "Castellano"     fr "Castellano"         sp "Castellano"]
-array set WIN  [list uk "You lose"       fr "Je t'ai bien gagn" sp "He ganado"]
-array set LOSE [list uk "You win"        fr "Tu m'as bien gagn" sp "Me has ganado"]
-array set NWIN [list uk "North wins"     fr "Nord a bien gagn"  sp "Norte ha ganado"]
-array set SWIN [list uk "South wins"     fr "Sud a bien gagn"   sp "Sur ha ganado"]
-array set DRAW [list uk "It's a draw"    fr "C'est mme score"   sp "Igualdad"]
-array set CSCO [list uk "Computer score" fr "Score ordinateur"   sp "Score del ordenador"]
-array set PSCO [list uk "Player score"   fr "Score joueur"       sp "Score del jugador"]
-array set P1CO [list uk "North score"    fr "Score nord"         sp "Score del norte"]
-array set P2CO [list uk "South score"    fr "Score sud"          sp "Score del sur"]
-array set DEPT [list uk "Depth"          fr "Profondeur"         sp "Profundidad"]
-array set TURN [list uk "Turn"           fr "Tour"               sp "Turno"]
-array set YES  [list uk "Yes"            fr "Oui"                sp "Si"]
-array set NO   [list uk "No"             fr "Non"                sp "No"]
-array set OK   [list uk "OK"             fr "OK"                 sp "VALE"]
-array set DEFA [list uk "DEFAULT" fr "DEFAUT" sp "DEFECTO"]
+array set SEED [list uk "seed(s)"        fr "graine(s)"          sp "semilla(s)"             de "Samen"]
+array set PLAY [list uk "Play"           fr "Jeu"                sp "Jugar"                  de "Spielen"]
+array set NEW  [list uk "New game"       fr "Nouvelle partie"    sp "Nueva partida"          de "Neues Spiel"]
+array set OPEN [list uk "Open"           fr "Ouvrir"             sp "Abrir"                  de "ffnen"]
+array set SAVE [list uk "Save"           fr "Sauver"             sp "Guardar"                de "Speichern"]
+array set UNDO [list uk "Undo"           fr "Annuler"            sp "Anular"                 de "Rckgngig"]
+array set QUIT [list uk "Quit"           fr "Quitter"            sp "Salir"                  de "Beenden"]
+array set PARA [list uk "Parameters"     fr "Paramtres"         sp "Parmetros"	     de "Parameter"]
+array set LEVE [list uk "Level"          fr "Niveau"             sp "Nivel"		     de "Spielniveau"]
+array set TWOP [list uk "Two players"    fr "Deux joueurs"       sp "Dos jugadores"	     de "Zwei Spieler"]
+array set OPPO [list uk "Computer level" fr "Ordinateur niveau"  sp "Ordenador nivel"	     de "Computer-Niveau"]
+array set STAR [list uk "First turn"     fr "Premier coup"       sp "Primer turno"	     de "Erster Zug"]
+array set LING [list uk "Language"       fr "Language"           sp "Lengua"		     de "Sprache"]
+array set BOTT [list uk "Bottom"         fr "Bas"                sp "Abajo"		     de "Unten"]
+array set TOP  [list uk "Top"            fr "Haut"               sp "Arriba"		     de "Oben"]
+array set CONF [list uk "Configure rule" fr "Configurer la rgle" sp "Configurar las reglas" de "Regeln konfigurieren"]
+array set DETA [list uk "Detailed rule"  fr "Rgle dtaille"    sp "Reglas detalladas"	     de "Detaillierte Regeln"]
+array set HELP [list uk "Help"           fr "Aide"               sp "Ayuda" 		     de "Hilfe"]
+array set RULE [list uk "Rules"          fr "Rgles"             sp "Reglas"		     de "Regeln"]
+array set ABOU [list uk "About"          fr "A propos"           sp "Sobre"		     de "ber"]
+array set UK   [list uk "English"        fr "English"            sp "English"	             de "English"]
+array set FR   [list uk "Franais"       fr "Franais"           sp "Franais"		     de "Franais"]
+array set SP   [list uk "Castellano"     fr "Castellano"         sp "Castellano"	     de "Castellano"]
+array set DE   [list uk "Deutsch"        fr "Deutsch"            sp "Deutsch"   	     de "Deutsch"]
+array set WIN  [list uk "You lose"       fr "Je t'ai bien gagn" sp "He ganado"		     de "Sie haben verloren"]
+array set LOSE [list uk "You win"        fr "Tu m'as bien gagn" sp "Me has ganado"	     de "Sie haben gewonnen"]
+array set NWIN [list uk "North wins"     fr "Nord a bien gagn"  sp "Norte ha ganado"	     de "Nord hat gewonnen"]
+array set SWIN [list uk "South wins"     fr "Sud a bien gagn"   sp "Sur ha ganado"	     de "Sd hat gewonnen"]
+array set DRAW [list uk "It's a draw"    fr "C'est mme score"   sp "Igualdad"		     de "Unentschieden"]
+array set CSCO [list uk "Computer score" fr "Score ordinateur"   sp "Score del ordenador"    de "Punkte des Computers"]
+array set PSCO [list uk "Player score"   fr "Score joueur"       sp "Score del jugador"	     de "Punkte des Spielers"]
+array set P1CO [list uk "North score"    fr "Score nord"         sp "Score del norte"	     de "Punkte von Nord"]
+array set P2CO [list uk "South score"    fr "Score sud"          sp "Score del sur"	     de "Punkte von Sd"]
+array set DEPT [list uk "Depth"          fr "Profondeur"         sp "Profundidad"	     de "Tiefe"]
+array set TURN [list uk "Turn"           fr "Tour"               sp "Turno"		     de "Runde"]
+array set YES  [list uk "Yes"            fr "Oui"                sp "Si"		     de "Ja"]
+array set NO   [list uk "No"             fr "Non"                sp "No"		     de "Nein"]
+array set OK   [list uk "OK"             fr "OK"                 sp "VALE"		     de "OK"]
+array set DEFA [list uk "DEFAULT" fr "DEFAUT" sp "DEFECTO" de "VOREINSTELLUNG"]
 array set MAXI [list uk "Maximum number E of holes that can be eaten"\
                      fr "Nombre maximum E de trous pouvant tre mangs"\
-                     sp "Cantidad mxima E de agujeros que comer"]
+                     sp "Cantidad mxima E de agujeros que comer"\
+		     de "Maximale Anzahl E der Mulden mit Samen, die gefangen werden knnen"]
 array set EATL [list uk "Eat the last E holes when attacking more than E holes"\
                      fr "Mange les E derniers trous lorsqu'on attaque plus de E trous"\
-                     sp "Se comen los E ltimos agujeros cuando se pasa del mximo E"]
+                     sp "Se comen los E ltimos agujeros cuando se pasa del mximo E"\
+		     de "Wenn mehr als E Mulden angegriffen werden, nur die Samen der letzten E Mulden gefangen nehmen"]
 array set EATN [list uk "Eat nothing when attacking more than E holes"\
                      fr "Ne mange rien lorsqu'on attaque plus de E trous"\
-                     sp "No se come nada cuando se pasa del mximo E"]
+                     sp "No se come nada cuando se pasa del mximo E"\
+		     de "Gar keinen Samen fangen, wenn mehr als E angegriffen werden"]
 array set EATA [list uk "Can eat all opponent seeds"\
                      fr "Peut manger toutes les graines adverses"\
-                     sp "Se puede comer todos los agujeros del adversario"]
+                     sp "Se puede comer todos los agujeros del adversario"\
+		     de "Man kann smtliche gegnerischen Samen fangen"]
 array set NOAL [list uk "Eat nothing when trying to eat all opponent seeds"\
                      fr "Ne mange rien lorsqu'on attaque toutes les graines adverses"\
-                     sp "No se come nada cuando se intenta comer todas las semillas adversas"]
+                     sp "No se come nada cuando se intenta comer todas las semillas adversas"\
+		     de "Gar keinen Samen fangen, wenn alle gegnerischen Samen angegriffen werden"]
 array set ATKA [list uk "Allow to play a move which attacks all opponent seeds"\
                      fr "Peut jouer un coup qui attaque toutes les graines adverses"\
-                     sp "Se puede atacar todos los agujeros del adversario"]
+                     sp "Se puede atacar todos los agujeros del adversario"\
+		     de "Man kann smtliche gegnerischen Samen angreifen"]
 array set NOAK [list uk "Forbidden to attack all opponent seeds excepted if this is the only possible move"\
                      fr "Interdiction d'attaquer toutes les graines adverses sauf si c'est le seul coup jouable"\
-                     sp "No se puede atacar todas las semillas adversas excepto si es la sola jugada posible"]
+                     sp "No se puede atacar todas las semillas adversas excepto si es la sola jugada posible"\
+		     de "Man kann nicht smtliche gegnerischen Samen angreifen, es sei denn, es ist der einzige mgliche Zug"]
 array set IFIL [list uk "Select file to import" \
                      fr "Choisir le fichier  importer" \
-                     sp "Elegir el fichero para importar"]
+                     sp "Elegir el fichero para importar"\
+		     de "Datei zum Importieren whlen"]
 array set SFIL [list uk "Select file to save" \
                      fr "Choisir le fichier  importer" \
-                     sp "Qu fichero quieres ?"]
+                     sp "Qu fichero quieres ?"\
+		     de "Datei zum Speichern whlen"]
 array set EFIL [list uk "ERROR when opening file" \
                      fr "ERREUR lors de l'ouverture du fichier" \
-                     sp "ERROR cuando se abre el fichero"]
+                     sp "ERROR cuando se abre el fichero"\
+		     de "FEHLER beim ffnen der Datei"]
 
 openConfigure
 
@@ -835,6 +880,7 @@ menu $m.lang -tearoff 0
 $m.lang add radio -label $UK($LANG) -variable LANG -value "uk" -command {changeLang}
 $m.lang add radio -label $FR($LANG) -variable LANG -value "fr" -command {changeLang}
 $m.lang add radio -label $SP($LANG) -variable LANG -value "sp" -command {changeLang}
+$m.lang add radio -label $DE($LANG) -variable LANG -value "de" -command {changeLang}
 $m add command -label $CONF($LANG) -command {configureRules}
 
 set m .menu.help
